@@ -39,7 +39,7 @@ sub Populate {
       'TitleFont', $CompositeWidget->{RefInfoDummies}->{Font}{DefaultTitle}
     ],
     -titleposition => [ 'PASSIVE', 'Titleposition', 'TitlePosition', 'center' ],
-    -width => [
+    -width         => [
       'SELF',  'width',
       'Width', $CompositeWidget->{RefInfoDummies}->{Canvas}{Width}
     ],
@@ -142,9 +142,9 @@ sub plot {
 sub _title {
   my ($CompositeWidget) = @_;
 
-  my $Title      = $CompositeWidget->cget( -title );
-  my $TitleColor = $CompositeWidget->cget( -titlecolor );
-  my $TitleFont  = $CompositeWidget->cget( -titlefont );
+  my $Title         = $CompositeWidget->cget( -title );
+  my $TitleColor    = $CompositeWidget->cget( -titlecolor );
+  my $TitleFont     = $CompositeWidget->cget( -titlefont );
   my $titleposition = $CompositeWidget->cget( -titleposition );
 
   # Title verification
@@ -168,27 +168,30 @@ sub _title {
   # display title
   my $anchor;
   if ( $titleposition eq 'left' ) {
-    $CompositeWidget->{RefInfoDummies}->{Title}{Ctitrex} = $WidthEmptyBeforeTitle;
+    $CompositeWidget->{RefInfoDummies}->{Title}{Ctitrex}
+      = $WidthEmptyBeforeTitle;
     $anchor = 'nw';
     $CompositeWidget->{RefInfoDummies}->{Title}{'-width'} = 0;
   }
-  elsif  ( $titleposition eq 'right' ) {
-    $CompositeWidget->{RefInfoDummies}->{Title}{Ctitrex} = $WidthEmptyBeforeTitle + $CompositeWidget->{RefInfoDummies}->{Axis}{Xaxis}{Width};
+  elsif ( $titleposition eq 'right' ) {
+    $CompositeWidget->{RefInfoDummies}->{Title}{Ctitrex}
+      = $WidthEmptyBeforeTitle
+      + $CompositeWidget->{RefInfoDummies}->{Axis}{Xaxis}{Width};
     $CompositeWidget->{RefInfoDummies}->{Title}{'-width'} = 0;
     $anchor = 'ne';
   }
-  else  {
+  else {
     $anchor = 'center';
   }
   $CompositeWidget->{RefInfoDummies}->{Title}{IdTitre}
     = $CompositeWidget->createText(
     $CompositeWidget->{RefInfoDummies}->{Title}{Ctitrex},
     $CompositeWidget->{RefInfoDummies}->{Title}{Ctitrey},
-    -text  => $Title,
-    -width => $CompositeWidget->{RefInfoDummies}->{Pie}{Width},
+    -text   => $Title,
+    -width  => $CompositeWidget->{RefInfoDummies}->{Pie}{Width},
     -anchor => $anchor,
     );
-    return if ( $anchor =~ m{^left|right$} );
+  return if ( $anchor =~ m{^left|right$} );
 
   # get title information
   my ($Height);
